Other functions
---------------

.. currentmodule:: contourpy

.. autofunction:: convert_filled

.. autofunction:: convert_lines

.. autofunction:: dechunk_filled

.. autofunction:: dechunk_lines

.. autofunction:: max_threads
